macroScript SubmitMaxToDeadline3 category:"Deadline" buttontext:"Deadline" tooltip:"Submit To Deadline"
(
	--------------------------------------------------------
	-- Submit MAX To Deadline Updater/Launcher
	-- Deadline submission script for 3dsmax
	-- Copyright (c) 2003-2011 Thinkbox Software Inc
	-- All rights reserved.
	--------------------------------------------------------

	local sttotal = timestamp()

	global SMTD_AutoLoadSuccessful
	global SMTD_TilesRendering
	global SMTD_RegionRendering
	global SMTD_StartupDialog_Rollout 
	try(destroyDialog SMTD_StartupDialog_Rollout )catch()
	local fullSuccess = false
	
	rollout SMTD_StartupDialog_Rollout "Submit Max To Deadline Loading..."
	(
		progressbar prg_loading color:green height:20 width:280
		label lbl_progress "Startup..."
	)
	createDialog SMTD_StartupDialog_Rollout 300 50
	
	
	SMTD_StartupDialog_Rollout.prg_loading.value = 15.0
	SMTD_StartupDialog_Rollout.lbl_progress.text = "Looking for Network Root..."
	local theNetworkRoot = ""
	local st = timestamp()
	-- call DeadlineCommand to find the network root (assume it is in the path)
	try
	(
		local result = -2
			
		local submitOutputFile = sysInfo.tempdir + "submitOutput.txt"
		local submitExitCodeFile = sysInfo.tempdir + "submitExitCode.txt"
		
		deleteFile submitOutputFile
		deleteFile submitExitCodeFile
				
		local commandArguments = "-outputfiles \"" + submitOutputFile + "\" \"" + submitExitCodeFile + "\" -getrepositoryroot"
		ShellLaunch "deadlinecommandbg.exe" commandArguments
				
		local startTimeStamp = timestamp()
		local ready = false
		while not ready do
		(
			sleep 0.15
			if doesFileExist submitExitCodeFile do
			(
				local theFile = openFile submitExitCodeFile
				try(result = readValue theFile)catch(result = -2)
				try(close theFile)catch()
				ready = true
			)	
			if timestamp() - startTimeStamp > 10000 then 
			(
				result = -3
				ready = true
			)	
		)
		
		if( result == 0 ) then
		(
			local resultFile = OpenFile submitOutputFile
			local resultMsg = ""
			if (resultFile != undefined) do
			(
				try(resultMsg = readLine resultFile)catch()
				try(close resultFile)catch()
			)
			
			theNetworkRoot = resultMsg
		)
		else
		(
			if result == -3 then
				messageBox "Timed out getting Repository Root from Deadline Command. (error code: 1003)"
			else
				messageBox "Failed to get Repository Root from Deadline Command. (error code: 1004)"	
		)
	)
	catch
		messageBox "Error calling Deadline Command to get Repository Root. (error code: 1005)"

	format "Resolving Network Path: %ms\n" (timestamp()-st)
	
	fn getFileInfoDotNet theFileName =
	(
		local fileLookup = dotnetobject "System.IO.DirectoryInfo" (getFileNamePath theFileName)
		local allMatchingFiles = #()
		try (
			allMatchingFiles = fileLookup.getFiles (filenamefrompath theFileName) 
		) catch()
		if allMatchingFiles.count == 1 then
		(
			local dotNetFile = allMatchingFiles[1]
			local fname = dotNetFile.FullName
			local date_ = dotNetFile.lastWriteTime.ToString()
			local size_ = dotNetFile.length
			#(fname, date_, size_)
		)
		else
			#()
	)	
	
	local theFilesToLoad = #(
		--#(1: File Name, 2: Base Error Code, 3: target folder, 4: fatal error)
		#("RegionManipulator.ms", 1040, #userStartupScripts,false,false),
		#("TileManipulator.ms", 1042, #userStartupScripts,false,false),
		#("SubmitMaxToDeadline_Functions.ms", 1004, #userScripts, true,false),
		#("SubmitMaxToDeadline.ms", 1030, #userScripts,true,false),
		#("SubmitMaxToDeadline_SanityCheck_Private.ms", 1024, #userScripts,false,true),
		#("SubmitMaxToDeadline_SanityCheck_General.ms", 1020, #userScripts,false,true),
		#("SubmitMaxToDeadline_SanityCheck.ms", 1022, #userScripts,false,false)
	)
	
	local theLocalLauncherFilename = (GetDir #userStartupScripts + "\\SMTD_Loader.ms")
	local localLauncherExists = doesFileExist theLocalLauncherFilename
	format "SMTD_AutoLoadSuccessful = %\n" ::SMTD_AutoLoadSuccessful
	
	local goOn = true
	for i = 1 to theFilesToLoad.count do
	(
		local st = timestamp()
		SMTD_StartupDialog_Rollout.prg_loading.value = 10 + (90.0*i/theFilesToLoad.count)
		SMTD_StartupDialog_Rollout.lbl_progress.text = "Loading File [" + theFilesToLoad[i][1] + "]"
		try( 
			local theScript = theNetworkRoot + "\\submission\\3dsmax\\" + theFilesToLoad[i][1]
			local theTarget = (GetDir theFilesToLoad[i][3] + "\\" + theFilesToLoad[i][1])
			if doesFileExist theScript then
			(
				local theInfo1 = getFileInfoDotNet theScript
				local theInfo2 = #("","","")
				if doesFileExist theTarget do
					theInfo2 = getFileInfoDotNet theTarget
				--format "Info1 = %\n" theInfo1
				--format "Info2 = %\n" theInfo2
				
				if theInfo1[2] != theInfo2[2] or theInfo1[3] != theInfo2[3] then
				(
					deleteFile theTarget
					copyFile theScript theTarget
					fileIn theTarget quiet:true		
					if theFilesToLoad[i][5] == true do SMTD_AutoLoadSuccessful = false
				)
				else
				(
					if not localLauncherExists or SMTD_AutoLoadSuccessful != true do 
						fileIn theTarget quiet:true	
				)
			)	
			else
			(
				messageBox ("Failed To Find the file ["+theFilesToLoad[i][1]+"] in Deadline Repository. (error code: "+ theFilesToLoad[i][2] as string  +")") title:"SMTD"
				if theFilesToLoad[i][4] == true do
				(
					local goOn = false
					exit
				)				
			)
		)
		catch
		(
			messageBox ("Failed To Load the file ["+theFilesToLoad[i][1]+"] from Deadline Repository. (error code: "+(theFilesToLoad[i][2]+1) as string+")") title:"SMTD" 
			if theFilesToLoad[i][4] == true do
			(
				local goOn = false
				exit
			)			
		)
		format "Loading %: %ms\n" theFilesToLoad[i][1] (timestamp()-st)
	)
	
	local theLocalLauncher = createFile theLocalLauncherFilename
	format "global SMTD_AutoLoadSuccessful = true\n" to:theLocalLauncher
	for i in theFilesToLoad where i[3] != #userStartupScripts do
	(
		format "try(fileIn (getDir % + \"/%\") quiet:true )catch(::SMTD_AutoLoadSuccessful = false)\n" i[3] i[1] to:theLocalLauncher
	)
	close theLocalLauncher
	
	SMTD_StartupDialog_Rollout.prg_loading.value = 100.0
	SMTD_StartupDialog_Rollout.lbl_progress.text = "Launching Submit Max To Deadline..."
	
	try(destroyDialog SMTD_StartupDialog_Rollout )catch()
	
	format "Total SMTD Launcher Time: %ms\n" (timestamp()-sttotal)
	
	if goOn do 
	(
		::SMTD_AutoLoadSuccessful = true
		macros.run "Thinkbox Software" "SubmitMaxToDeadline"
	)
)
